@@ -2,7 +2,9 @@ use 5.14.0;
 
 package Dist::Zilla::Plugin::MapMetro::MintMapFiles;
 
-our $VERSION = '0.1500'; # VERSION
+# ABSTRACT: Mint files
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.1501';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::InlineFiles';
@@ -35,11 +37,11 @@ override 'merged_section_data' => sub {
 
 =head1 NAME
 
-Dist::Zilla::Plugin::MapMetro::MintMapFiles
+Dist::Zilla::Plugin::MapMetro::MintMapFiles - Mint files
 
 =head1 VERSION
 
-Version 0.1500, released 2015-02-01.
+Version 0.1501, released 2021-03-29.
 
 =head1 SOURCE
 
@@ -55,7 +57,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson.
+This software is copyright (c) 2021 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
